@@ -16,14 +16,15 @@ logger = logging.getLogger(__name__)
 
 
 class SchemaGenerator(object):
-    def __init__(self,
-                path_to_json_ld: str = None,
-                schema_explorer: SchemaExplorer = None,
-                requires_dependency_relationship: str = "requiresDependency",  # optional parameter(s) with default value
-                requires_range: str = "rangeIncludes",
-                range_value_relationship: str = "rangeValue",
-                requires_component_relationship: str = "requiresComponent"
-                ) -> None:
+    def __init__(
+        self,
+        path_to_json_ld: str = None,
+        schema_explorer: SchemaExplorer = None,
+        requires_dependency_relationship: str = "requiresDependency",  # optional parameter(s) with default value
+        requires_range: str = "rangeIncludes",
+        range_value_relationship: str = "rangeValue",
+        requires_component_relationship: str = "requiresComponent",
+    ) -> None:
         """Create / Initialize object of type SchemaGenerator().
 
         Methods / utilities that are part of this module can be used to generate JSON validation schemas for different schema.org
@@ -45,9 +46,9 @@ class SchemaGenerator(object):
 
         if schema_explorer is None:
 
-            assert self.jsonld_path is not None, (
-                "You must provide either `path_to_json_ld` or `schema_explorer`."
-            )
+            assert (
+                self.jsonld_path is not None
+            ), "You must provide either `path_to_json_ld` or `schema_explorer`."
 
             self.jsonld_path_root, jsonld_ext = os.path.splitext(self.jsonld_path)
 
@@ -82,34 +83,30 @@ class SchemaGenerator(object):
         self.range_value_relationship = range_value_relationship
         self.requires_component_relationship = requires_component_relationship
 
-
-    def get_edges_by_relationship(self,
-                                node: str,
-                                relationship: str) -> List[str]:
+    def get_edges_by_relationship(self, node: str, relationship: str) -> List[str]:
         """
-            See class definition in SchemaExplorer
-            TODO: possibly remove this wrapper and refactor downstream code to call from SchemaExplorer
+        See class definition in SchemaExplorer
+        TODO: possibly remove this wrapper and refactor downstream code to call from SchemaExplorer
         """
 
         return self.se.get_edges_by_relationship(node, relationship)
 
-
-    def get_adjacent_nodes_by_relationship(self,
-                                          node: str,
-                                          relationship: str) -> List[str]:
+    def get_adjacent_nodes_by_relationship(
+        self, node: str, relationship: str
+    ) -> List[str]:
 
         """
-            See class definition in SchemaExplorer
-            TODO: possibly remove this wrapper and refactor downstream code to call from SchemaExplorer
+        See class definition in SchemaExplorer
+        TODO: possibly remove this wrapper and refactor downstream code to call from SchemaExplorer
         """
 
         return self.se.get_adjacent_nodes_by_relationship(node, relationship)
 
-
-    def get_subgraph_by_edge_type(self,
-                                  graph: nx.MultiDiGraph,
-                                  relationship:str) -> nx.DiGraph:
+    def get_subgraph_by_edge_type(
+        self, graph: nx.MultiDiGraph, relationship: str
+    ) -> nx.DiGraph:
         """Get a subgraph containing all edges of a given type (aka relationship).
+        TODO: possibly move method to SchemaExplorer and refactor downstream code to call from SchemaExplorer
 
         Args:
             graph: input multi digraph (aka hypergraph)
@@ -121,31 +118,33 @@ class SchemaGenerator(object):
 
         # prune the metadata model graph so as to include only those edges that match the relationship type
         rel_edges = []
-        for (u, v, key, c) in graph.edges(data=True, keys=True):
+        for (u, v, key, c) in graph.out_edges(data=True, keys=True):
             if key == relationship:
                 rel_edges.append((u, v))
 
         relationship_subgraph = nx.DiGraph()
         relationship_subgraph.add_edges_from(rel_edges)
 
+        return relationship_subgraph
 
-    def get_descendants_by_edge_type(self,
-                                    source_node: str,
-                                    relationship: str,
-                                    connected: bool = True,
-                                    ordered: bool = False) -> List[str]:
+    def get_descendants_by_edge_type(
+        self,
+        source_node: str,
+        relationship: str,
+        connected: bool = True,
+        ordered: bool = False,
+    ) -> List[str]:
 
         """
-            See class definition in SchemaExplorer
-            TODO: possibly remove this wrapper and refactor downstream code to call from SchemaExplorer
+        See class definition in SchemaExplorer
+        TODO: possibly remove this wrapper and refactor downstream code to call from SchemaExplorer
         """
 
-        return self.se.get_descendants_by_edge_type(source_node, relationship, connected, ordered)
+        return self.se.get_descendants_by_edge_type(
+            source_node, relationship, connected, ordered
+        )
 
-
-
-    def get_component_requirements(self,
-                                  source_component: str) -> List[str]:
+    def get_component_requirements(self, source_component: str) -> List[str]:
         """Get all components that are associated with a given source component and are required by it.
 
         Args:
@@ -155,15 +154,40 @@ class SchemaGenerator(object):
             List of nodes that are descendants from the source component are are related to the source through a specific component relationship.
         """
 
-        req_components = list(reversed(self.get_descendants_by_edge_type(source_component, self.requires_component_relationship, ordered = True)))
+        req_components = list(
+            reversed(
+                self.get_descendants_by_edge_type(
+                    source_component, self.requires_component_relationship, ordered=True
+                )
+            )
+        )
 
         return req_components
 
+    def get_component_requirements_graph(self, source_component: str) -> nx.DiGraph:
+        """Get all components that are associated with a given source component and are required by it; return the components as a dependency graph (i.e. a DAG).
 
-    def get_node_dependencies(self,
-                            source_node: str,
-                            display_names: bool = True,
-                            schema_ordered: bool = True) -> List[str]:
+        Args:
+            source_component: source component for which we need to find all required downstream components.
+
+        Returns:
+            A subgraph of the schema graph induced on nodes that are descendants from the source component and are related to the source through a specific component relationship.
+        """
+
+        # get a list of required component nodes
+        req_components = self.get_component_requirements(source_component)
+        
+        # get the schema graph
+        mm_graph = self.se.get_nx_schema()
+
+        # get the subgraph induced on required component nodes
+        req_components_graph = self.get_subgraph_by_edge_type(mm_graph, self.requires_component_relationship).subgraph(req_components)
+
+        return req_components_graph
+
+    def get_node_dependencies(
+        self, source_node: str, display_names: bool = True, schema_ordered: bool = True
+    ) -> List[str]:
         """Get the immediate dependencies that are related to a given source node.
 
         Args:
@@ -182,7 +206,9 @@ class SchemaGenerator(object):
             # get dependencies in the same order in which they are defined in the schema
             required_dependencies = self.se.explore_class(source_node)["dependencies"]
         else:
-            required_dependencies = self.get_adjacent_nodes_by_relationship(source_node, self.requires_dependency_relationship)
+            required_dependencies = self.get_adjacent_nodes_by_relationship(
+                source_node, self.requires_dependency_relationship
+            )
 
         if display_names:
             # get display names of dependencies
@@ -195,10 +221,7 @@ class SchemaGenerator(object):
 
         return required_dependencies
 
-
-    def get_node_range(self,
-                      node_label: str,
-                      display_names: bool = True) -> List[str]:
+    def get_node_range(self, node_label: str, display_names: bool = True) -> List[str]:
         """Get the range, i.e., all the valid values that are associated with a node label.
 
         Args:
@@ -213,8 +236,10 @@ class SchemaGenerator(object):
             # get node range in the order defined in schema for given node
             required_range = self.se.explore_class(node_label)["range"]
         except KeyError:
-            raise ValueError(f"The source node {node_label} does not exist in the graph. "
-                            "Please use a different node.")
+            raise ValueError(
+                f"The source node {node_label} does not exist in the graph. "
+                "Please use a different node."
+            )
 
         if display_names:
             # get the display name(s) of all dependencies
@@ -227,9 +252,7 @@ class SchemaGenerator(object):
 
         return required_range
 
-
-    def get_node_label(self,
-                      node_display_name: str) -> str:
+    def get_node_label(self, node_display_name: str) -> str:
         """Get the node label for a given display name.
 
         Args:
@@ -244,7 +267,9 @@ class SchemaGenerator(object):
         mm_graph = self.se.get_nx_schema()
 
         node_class_label = self.se.get_class_label_from_display_name(node_display_name)
-        node_property_label = self.se.get_property_label_from_display_name(node_display_name)
+        node_property_label = self.se.get_property_label_from_display_name(
+            node_display_name
+        )
 
         if node_class_label in mm_graph.nodes:
             node_label = node_class_label
@@ -255,9 +280,7 @@ class SchemaGenerator(object):
 
         return node_label
 
-
-    def get_node_definition(self,
-                           node_display_name: str) -> str:
+    def get_node_definition(self, node_display_name: str) -> str:
         """Get the node definition, i.e., the "comment" associated with a given node display name.
 
         Args:
@@ -276,7 +299,6 @@ class SchemaGenerator(object):
 
         return node_definition
 
-
     def get_node_validation_rules(self, node_display_name: str) -> str:
         """Get validation rules associated with a node,
 
@@ -296,9 +318,7 @@ class SchemaGenerator(object):
 
         return node_validation_rules
 
-
-    def is_node_required(self,
-                        node_display_name: str) -> bool:
+    def is_node_required(self, node_display_name: str) -> bool:
         """Check if a given node is required or not.
 
         Note: The possible options that a node can be associated with -- "required" / "optional".
@@ -317,10 +337,9 @@ class SchemaGenerator(object):
 
         return node_required
 
-
-    def get_nodes_display_names(self,
-                               node_list: List[str],
-                               mm_graph: nx.MultiDiGraph) -> List[str]:
+    def get_nodes_display_names(
+        self, node_list: List[str], mm_graph: nx.MultiDiGraph
+    ) -> List[str]:
         """Get display names associated with the given list of nodes.
 
         Args:
@@ -329,15 +348,15 @@ class SchemaGenerator(object):
         Returns:
             List of display names.
         """
-        node_list_display_names = [mm_graph.nodes[node]["displayName"] for node in node_list]
+        node_list_display_names = [
+            mm_graph.nodes[node]["displayName"] for node in node_list
+        ]
 
         return node_list_display_names
 
-
-    def get_range_schema(self,
-                        node_range: List[str],
-                        node_name: str,
-                        blank = False) -> Dict[str, Dict[str, List[str]]]:
+    def get_range_schema(
+        self, node_range: List[str], node_name: str, blank=False
+    ) -> Dict[str, Dict[str, List[str]]]:
         """Add a list of nodes to the "enum" key in a given JSON schema object.
 
         Args:
@@ -356,11 +375,9 @@ class SchemaGenerator(object):
 
         return schema_node_range
 
-
-    def get_array_schema(self,
-                        node_range: List[str],
-                        node_name: str,
-                        blank = False) -> Dict[str, Dict[str, List[str]]]:
+    def get_array_schema(
+        self, node_range: List[str], node_name: str, blank=False
+    ) -> Dict[str, Dict[str, List[str]]]:
         """Add a list of nodes to the "enum" key in a given JSON schema object.
            Allow a node to be mapped to any subset of the list
 
@@ -375,20 +392,18 @@ class SchemaGenerator(object):
         """
 
         schema_node_range_array = {
-                                    node_name:{
-                                        "type": "array",
-                                        "items": {
-                                            "enum": node_range + [""] if blank else node_range
-                                        },
-                                        "maxItems": len(node_range)
-                                    }
+            node_name: {
+                "type": "array",
+                "items": {"enum": node_range + [""] if blank else node_range},
+                "maxItems": len(node_range),
+            }
         }
 
         return schema_node_range_array
 
-
-    def get_non_blank_schema(self,
-                            node_name: str) -> Dict:    # can't define heterogenous Dict generic types
+    def get_non_blank_schema(
+        self, node_name: str
+    ) -> Dict:  # can't define heterogenous Dict generic types
         """Get a schema rule that does not allow null or empty values.
 
         Args:
@@ -401,7 +416,6 @@ class SchemaGenerator(object):
 
         return non_blank_schema
 
-
     def is_required(self, node_name: str, mm_graph: nx.MultiDiGraph) -> bool:
         """
         Check if a node is required
@@ -416,10 +430,7 @@ class SchemaGenerator(object):
         """
         return mm_graph.nodes[node_name]["required"]
 
-
-    def get_json_schema_requirements(self,
-                                    source_node: str,
-                                    schema_name: str) -> Dict:
+    def get_json_schema_requirements(self, source_node: str, schema_name: str) -> Dict:
         """Consolidated method that aims to gather dependencies and value constraints across terms / nodes in a schema.org schema and store them in a jsonschema /JSON Schema schema.
 
         It does so for any given node in the schema.org schema (recursively) using the given node as starting point in the following manner:
@@ -435,24 +446,34 @@ class SchemaGenerator(object):
         """
         json_schema = {
             "$schema": "http://json-schema.org/draft-07/schema#",
-            "$id":"http://example.com/" + schema_name,
+            "$id": "http://example.com/" + schema_name,
             "title": schema_name,
             "type": "object",
-            "properties":{},
-            "required":[],
-            "allOf":[]
+            "properties": {},
+            "required": [],
+            "allOf": [],
         }
 
         # get graph corresponding to data model schema
         mm_graph = self.se.get_nx_schema()
 
-        nodes_to_process = []   # list of nodes to be checked for dependencies, starting with the source node
-        processed_nodes = []    # keep of track of nodes whose dependencies have been processed
-        reverse_dependencies = {}   # maintain a map between conditional nodes and their dependencies (reversed) -- {dependency : conditional_node}
-        range_domain_map = {}   # maintain a map between range nodes and their domain nodes {range_value : domain_value}
-                                # the domain node is very likely the parentof ("parentOf" relationship) of the range node
+        nodes_to_process = (
+            []
+        )  # list of nodes to be checked for dependencies, starting with the source node
+        processed_nodes = (
+            []
+        )  # keep of track of nodes whose dependencies have been processed
+        reverse_dependencies = (
+            {}
+        )  # maintain a map between conditional nodes and their dependencies (reversed) -- {dependency : conditional_node}
+        range_domain_map = (
+            {}
+        )  # maintain a map between range nodes and their domain nodes {range_value : domain_value}
+        # the domain node is very likely the parentof ("parentOf" relationship) of the range node
 
-        root_dependencies = self.get_adjacent_nodes_by_relationship(source_node, self.requires_dependency_relationship)
+        root_dependencies = self.get_adjacent_nodes_by_relationship(
+            source_node, self.requires_dependency_relationship
+        )
 
         # if root_dependencies is empty it means that a class with name 'source_node' exists
         # in the schema, but it is not a valid component
@@ -469,12 +490,16 @@ class SchemaGenerator(object):
                 # node is being processed
                 node_is_processed = True
 
-                node_range = self.get_adjacent_nodes_by_relationship(process_node, self.range_value_relationship)
+                node_range = self.get_adjacent_nodes_by_relationship(
+                    process_node, self.range_value_relationship
+                )
 
                 # get node range display name
                 node_range_d = self.get_nodes_display_names(node_range, mm_graph)
 
-                node_dependencies = self.get_adjacent_nodes_by_relationship(process_node, self.requires_dependency_relationship)
+                node_dependencies = self.get_adjacent_nodes_by_relationship(
+                    process_node, self.requires_dependency_relationship
+                )
 
                 # get process node display name
                 node_display_name = mm_graph.nodes[process_node]["displayName"]
@@ -490,14 +515,18 @@ class SchemaGenerator(object):
                 node_required = self.is_required(process_node, mm_graph)
 
                 # get any additional validation rules associated with this node (e.g. can this node be mapped to a list of other nodes)
-                node_validation_rules = self.get_node_validation_rules(node_display_name)
+                node_validation_rules = self.get_node_validation_rules(
+                    node_display_name
+                )
 
                 if node_display_name in reverse_dependencies:
                     # if node has conditionals set schema properties and conditional dependencies
                     # set schema properties
                     if node_range:
                         # if process node has valid value range set it in schema properties
-                        schema_valid_vals = self.get_range_schema(node_range_d, node_display_name, blank = True)
+                        schema_valid_vals = self.get_range_schema(
+                            node_range_d, node_display_name, blank=True
+                        )
 
                         if node_validation_rules:
                             # if this node has extra validation rules process them
@@ -506,11 +535,13 @@ class SchemaGenerator(object):
                             if "list" in node_validation_rules:
                                 # if this node can be mapped to a list of nodes
                                 # set its schema accordingly
-                                schema_valid_vals = self.get_array_schema(node_range_d, node_display_name, blank = True)
+                                schema_valid_vals = self.get_array_schema(
+                                    node_range_d, node_display_name, blank=True
+                                )
 
                     else:
                         # otherwise, by default allow any values
-                        schema_valid_vals = {node_display_name:{}}
+                        schema_valid_vals = {node_display_name: {}}
 
                     json_schema["properties"].update(schema_valid_vals)
 
@@ -527,44 +558,69 @@ class SchemaGenerator(object):
                             for domain_node in domain_nodes:
 
                                 # set range of conditional node schema
-                                conditional_properties.update({"properties":{domain_node:{"enum":[node]}}, "required":[domain_node]})
+                                conditional_properties.update(
+                                    {
+                                        "properties": {domain_node: {"enum": [node]}},
+                                        "required": [domain_node],
+                                    }
+                                )
 
                                 # given node conditional are satisfied, this process node (which is dependent on these conditionals) has to be set or not depending on whether it is required
                                 if node_range:
-                                    dependency_properties = self.get_range_schema(node_range_d, node_display_name, blank = not node_required)
+                                    dependency_properties = self.get_range_schema(
+                                        node_range_d,
+                                        node_display_name,
+                                        blank=not node_required,
+                                    )
 
                                     if node_validation_rules:
                                         if "list" in node_validation_rules:
-                                            #TODO: get_range_schema and get_range_schema have similar behavior - combine in one module
-                                            dependency_properties = self.get_array_schema(node_range_d, node_display_name, blank = not node_required)
+                                            # TODO: get_range_schema and get_range_schema have similar behavior - combine in one module
+                                            dependency_properties = (
+                                                self.get_array_schema(
+                                                    node_range_d,
+                                                    node_display_name,
+                                                    blank=not node_required,
+                                                )
+                                            )
 
                                 else:
                                     if node_required:
-                                        dependency_properties = self.get_non_blank_schema(node_display_name)
+                                        dependency_properties = (
+                                            self.get_non_blank_schema(node_display_name)
+                                        )
                                     else:
-                                        dependency_properties = {node_display_name:{}}
+                                        dependency_properties = {node_display_name: {}}
                                 schema_conditional_dependencies = {
-                                        "if": conditional_properties,
-                                        "then":{
-                                            "properties":dependency_properties,
-                                            "required":[node_display_name]
-                                        }
+                                    "if": conditional_properties,
+                                    "then": {
+                                        "properties": dependency_properties,
+                                        "required": [node_display_name],
+                                    },
                                 }
 
                                 # update conditional-dependency rules in json schema
-                                json_schema["allOf"].append(schema_conditional_dependencies)
+                                json_schema["allOf"].append(
+                                    schema_conditional_dependencies
+                                )
 
                 else:
                     # node doesn't have conditionals
                     if node_required:
                         if node_range:
-                            schema_valid_vals = self.get_range_schema(node_range_d, node_display_name, blank = False)
+                            schema_valid_vals = self.get_range_schema(
+                                node_range_d, node_display_name, blank=False
+                            )
 
                             if node_validation_rules:
                                 if "list" in node_validation_rules:
-                                    schema_valid_vals = self.get_array_schema(node_range_d, node_display_name, blank = False)
+                                    schema_valid_vals = self.get_array_schema(
+                                        node_range_d, node_display_name, blank=False
+                                    )
                         else:
-                            schema_valid_vals = self.get_non_blank_schema(node_display_name)
+                            schema_valid_vals = self.get_non_blank_schema(
+                                node_display_name
+                            )
 
                         json_schema["properties"].update(schema_valid_vals)
                         # add node to required fields
@@ -574,14 +630,18 @@ class SchemaGenerator(object):
                         # node doesn't have conditionals and is not required; it belongs in the schema only if it is in root's dependencies
 
                         if node_range:
-                            schema_valid_vals = self.get_range_schema(node_range_d, node_display_name, blank = True)
+                            schema_valid_vals = self.get_range_schema(
+                                node_range_d, node_display_name, blank=True
+                            )
 
                             if node_validation_rules:
                                 if "list" in node_validation_rules:
-                                    schema_valid_vals = self.get_array_schema(node_range_d, node_display_name, blank = True)
+                                    schema_valid_vals = self.get_array_schema(
+                                        node_range_d, node_display_name, blank=True
+                                    )
 
                         else:
-                            schema_valid_vals = {node_display_name:{}}
+                            schema_valid_vals = {node_display_name: {}}
 
                         json_schema["properties"].update(schema_valid_vals)
 
@@ -592,7 +652,9 @@ class SchemaGenerator(object):
                         node_is_processed = False
 
                 # add process node as a conditional to its dependencies
-                node_dependencies_d = self.get_nodes_display_names(node_dependencies, mm_graph)
+                node_dependencies_d = self.get_nodes_display_names(
+                    node_dependencies, mm_graph
+                )
 
                 for dep in node_dependencies_d:
                     if not dep in reverse_dependencies:
@@ -618,7 +680,6 @@ class SchemaGenerator(object):
                 # exit the loop
                 break
 
-
         logger.info("JSON schema successfully generated from schema.org schema!")
 
         # if no conditional dependencies were added we can't have an empty 'AllOf' block in the schema, so remove it
@@ -626,7 +687,9 @@ class SchemaGenerator(object):
             del json_schema["allOf"]
 
         # Check if config value is provided; otherwise, set to None
-        json_schema_log_file = query_dict(CONFIG.DATA, ("model", "input", "log_location"))
+        json_schema_log_file = query_dict(
+            CONFIG.DATA, ("model", "input", "log_location")
+        )
 
         # If no config value and SchemaGenerator was initialized with
         # a JSON-LD path, construct
@@ -645,7 +708,7 @@ class SchemaGenerator(object):
         else:
             os.makedirs(os.path.dirname(json_schema_log_file), exist_ok=True)
             with open(json_schema_log_file, "w") as js_f:
-                json.dump(json_schema, js_f, indent = 2)
+                json.dump(json_schema, js_f, indent=2)
 
         logger.info(f"JSON schema file log stored as {json_schema_log_file}")
 
