@@ -14,8 +14,14 @@ import pandas as pd
 import synapseclient
 import synapseutils
 
-from synapseclient import (Synapse, File, Folder, EntityViewSchema,
-                           EntityViewType, Column)
+from synapseclient import (
+    Synapse,
+    File,
+    Folder,
+    EntityViewSchema,
+    EntityViewType,
+    Column,
+)
 from synapseclient.table import CsvFileTable
 from synapseclient.annotations import from_synapse_annotations
 from synapseclient.core.exceptions import SynapseHTTPError, SynapseAuthenticationError
@@ -37,6 +43,7 @@ class SynapseStorage(BaseStorage):
 
     TODO: Need to define the interface and rename and/or refactor some of the methods below.
     """
+
     def __init__(
         self,
         token: str = None,  # optional parameter retrieved from browser cookie
@@ -57,35 +64,15 @@ class SynapseStorage(BaseStorage):
             syn_store = SynapseStorage()
         """
 
-        # If no token is provided, try retrieving access token from environment
-        if not token and not access_token:
-            access_token = os.getenv("SYNAPSE_ACCESS_TOKEN")
-
-        # login using a token
-        if token:
-            self.syn = synapseclient.Synapse()
-
-            try:
-                self.syn.login(sessionToken=token, silent=True)
-            except synapseclient.core.exceptions.SynapseHTTPError:
-                raise ValueError(
-                    "Please make sure you are logged into synapse.org.")
-        elif access_token:
-            self.syn = synapseclient.Synapse()
-            self.syn.default_headers[
-                "Authorization"] = f"Bearer {access_token}"
-        else:
-            # login using synapse credentials provided by user in .synapseConfig (default) file
-            self.syn = synapseclient.Synapse(
-                configPath=CONFIG.SYNAPSE_CONFIG_PATH)
-            self.syn.login(silent=True)
+        self.syn = self.login(token, access_token)
 
         try:
             self.storageFileview = CONFIG["synapse"]["master_fileview"]
 
             # get data in administrative fileview for this pipeline
             self.storageFileviewTable = self.syn.tableQuery(
-                "SELECT * FROM " + self.storageFileview).asDataFrame()
+                "SELECT * FROM " + self.storageFileview
+            ).asDataFrame()
 
             self.manifest = CONFIG["synapse"]["manifest_filename"]
         except KeyError:
@@ -97,37 +84,64 @@ class SynapseStorage(BaseStorage):
         except ValueError:
             raise MissingConfigValueError(("synapse", "master_fileview"))
 
+    @staticmethod
+    def login(token=None, access_token=None):
+        # If no token is provided, try retrieving access token from environment
+        if not token and not access_token:
+            access_token = os.getenv("SYNAPSE_ACCESS_TOKEN")
+
+        # login using a token
+        if token:
+            syn = synapseclient.Synapse()
+
+            try:
+                syn.login(sessionToken=token, silent=True)
+            except synapseclient.core.exceptions.SynapseHTTPError:
+                raise ValueError("Please make sure you are logged into synapse.org.")
+        elif access_token:
+            syn = synapseclient.Synapse()
+            syn.default_headers["Authorization"] = f"Bearer {access_token}"
+        else:
+            # login using synapse credentials provided by user in .synapseConfig (default) file
+            syn = synapseclient.Synapse(configPath=CONFIG.SYNAPSE_CONFIG_PATH)
+            syn.login(silent=True)
+
+        return syn
 
     def getPaginatedRestResults(self, currentUserId: str) -> Dict[str, str]:
         """Gets the paginated results of the REST call to Synapse to check what projects the current user has access to.
 
         Args:
             currentUserId: synapse id for the user whose projects we want to get.
-        
+
         Returns:
             A dictionary with a next page token and the results.
         """
         all_results = self.syn.restGET(
-            '/projects/user/{principalId}'.format(principalId=currentUserId))
+            "/projects/user/{principalId}".format(principalId=currentUserId)
+        )
 
-        while 'nextPageToken' in all_results:  # iterate over next page token in results while there is any
+        while (
+            "nextPageToken" in all_results
+        ):  # iterate over next page token in results while there is any
             results_token = self.syn.restGET(
-                '/projects/user/{principalId}?nextPageToken={nextPageToken}'.
-                format(principalId=currentUserId,
-                       nextPageToken=all_results['nextPageToken']))
-            all_results['results'].extend(results_token['results'])
+                "/projects/user/{principalId}?nextPageToken={nextPageToken}".format(
+                    principalId=currentUserId,
+                    nextPageToken=all_results["nextPageToken"],
+                )
+            )
+            all_results["results"].extend(results_token["results"])
 
-            if 'nextPageToken' in results_token:
-                all_results['nextPageToken'] = results_token['nextPageToken']
+            if "nextPageToken" in results_token:
+                all_results["nextPageToken"] = results_token["nextPageToken"]
             else:
-                del (all_results['nextPageToken'])
+                del all_results["nextPageToken"]
 
         return all_results
 
-
     def getStorageProjects(self) -> List[str]:
         """Gets all storage projects the current user has access to, within the scope of the 'storageFileview' attribute.
-        
+
         Returns:
             A list of storage projects the current user has access to; the list consists of tuples (projectId, projectName).
         """
@@ -147,7 +161,7 @@ class SynapseStorage(BaseStorage):
 
         # prune results json filtering project id
         currentUserProjects = [
-            currentUserProject.get('id')
+            currentUserProject.get("id")
             for currentUserProject in currentUserProjects["results"]
         ]
 
@@ -164,13 +178,12 @@ class SynapseStorage(BaseStorage):
 
         return sorted_projects_list
 
-
     def getStorageDatasetsInProject(self, projectId: str) -> List[str]:
         """Gets all datasets in folder under a given storage project that the current user has access to.
-        
+
         Args:
             projectId: synapse ID of a storage project.
-        
+
         Returns:
             A list of datasets within the given storage project; the list consists of tuples (datasetId, datasetName).
             None: If the projectId cannot be found on Synapse.
@@ -182,12 +195,14 @@ class SynapseStorage(BaseStorage):
         if "contentType" in self.storageFileviewTable.columns:
             foldersTable = self.storageFileviewTable[
                 (self.storageFileviewTable["contentType"] == "dataset")
-                & (self.storageFileviewTable["projectId"] == projectId)]
+                & (self.storageFileviewTable["projectId"] == projectId)
+            ]
             areDatasets = True
         else:
             foldersTable = self.storageFileviewTable[
                 (self.storageFileviewTable["type"] == "folder")
-                & (self.storageFileviewTable["parentId"] == projectId)]
+                & (self.storageFileviewTable["parentId"] == projectId)
+            ]
 
         # get an array of tuples (folderId, folderName)
         # some folders are part of datasets; others contain datasets
@@ -198,20 +213,18 @@ class SynapseStorage(BaseStorage):
 
         datasetList = []
         folderProperties = ["id", "name"]
-        for folder in list(foldersTable[folderProperties].itertuples(
-                index=False, name=None)):
+        for folder in list(
+            foldersTable[folderProperties].itertuples(index=False, name=None)
+        ):
             datasetList.append(folder)
 
         sorted_dataset_list = sorted(datasetList, key=lambda tup: tup[0])
 
         return sorted_dataset_list
 
-
     def getFilesInStorageDataset(
-            self,
-            datasetId: str,
-            fileNames: List = None,
-            fullpath: bool = True) -> List[Tuple[str, str]]:
+        self, datasetId: str, fileNames: List = None, fullpath: bool = True
+    ) -> List[Tuple[str, str]]:
         """Gets all files in a given dataset folder.
 
         Args:
@@ -220,9 +233,9 @@ class SynapseStorage(BaseStorage):
             metadata manifests); if fileNames is not None, all files matching the names in the fileNames list are returned if present.
             fullpath: if True return the full path as part of this filename; otherwise return just base filename
 
-        Returns: 
+        Returns:
             A list of files; the list consists of tuples (fileId, fileName).
-            
+
         Raises:
             ValueError: Dataset ID not found.
         """
@@ -238,9 +251,9 @@ class SynapseStorage(BaseStorage):
             # iterate over all files in a folder
             for filename in filenames:
 
-                if (not "manifest" in filename[0]
-                        and not fileNames) or (not fileNames == None
-                                               and filename[0] in fileNames):
+                if (not "manifest" in filename[0] and not fileNames) or (
+                    not fileNames == None and filename[0] in fileNames
+                ):
 
                     # don't add manifest to list of files unless it is specified in the list of specified fileNames; return all found files
                     # except the manifest if no fileNames have been specified
@@ -248,18 +261,16 @@ class SynapseStorage(BaseStorage):
 
                     if fullpath:
                         # append directory path to filename
-                        filename = (dirpath[0] + "/" + filename[0],
-                                    filename[1])
+                        filename = (dirpath[0] + "/" + filename[0], filename[1])
 
                     # add file name file id tuple, rearranged so that id is first and name follows
                     file_list.append(filename[::-1])
 
         return file_list
 
-
-    def getDatasetManifest(self,
-                           datasetId: str,
-                           downloadFile: bool = False) -> List[str]:
+    def getDatasetManifest(
+        self, datasetId: str, downloadFile: bool = False
+    ) -> List[str]:
         """Gets the manifest associated with a given dataset.
 
         Args:
@@ -276,8 +287,9 @@ class SynapseStorage(BaseStorage):
         all_files = self.storageFileviewTable
         manifest = all_files[
             (all_files["name"] == os.path.basename(self.manifest))
-            & (all_files["parentId"] == datasetId)]
-        manifest = manifest[['id', 'name']]
+            & (all_files["parentId"] == datasetId)
+        ]
+        manifest = manifest[["id", "name"]]
 
         # if there is no pre-exisiting manifest in the specified dataset
         if manifest.empty:
@@ -287,13 +299,14 @@ class SynapseStorage(BaseStorage):
             # if the downloadFile option is set to True
             if downloadFile:
                 # retrieve data from synapse
-                manifest_syn_id = manifest['id'][0]
+                manifest_syn_id = manifest["id"][0]
 
                 # pass synID to synapseclient.Synapse.get() method to download (and overwrite) file to a location
                 manifest_data = self.syn.get(
                     manifest_syn_id,
                     downloadLocation=CONFIG["synapse"]["manifest_folder"],
-                    ifcollision="overwrite.local")
+                    ifcollision="overwrite.local",
+                )
 
                 return manifest_data
 
@@ -302,7 +315,6 @@ class SynapseStorage(BaseStorage):
 
             return manifest_syn_id
 
-
     def updateDatasetManifestFiles(self, datasetId: str) -> str:
         """Fetch the names and entity IDs of all current files in dataset in store, if any; update dataset's manifest with new files, if any.
 
@@ -319,7 +331,8 @@ class SynapseStorage(BaseStorage):
             # no manifest exists yet: abort
             raise FileNotFoundError(
                 f"Manifest file {CONFIG['synapse']['manifest_filename']} "
-                f"cannot be found in {datasetId} dataset folder.")
+                f"cannot be found in {datasetId} dataset folder."
+            )
 
         manifest_filepath = self.syn.get(manifest_id).path
         manifest = pd.read_csv(manifest_filepath)
@@ -341,64 +354,85 @@ class SynapseStorage(BaseStorage):
                     new_files["entityId"].append(file_id)
 
             # update manifest so that it contain new files
-            #manifest = pd.DataFrame(new_files)
+            # manifest = pd.DataFrame(new_files)
             new_files = pd.DataFrame(new_files)
-            manifest = pd.concat([new_files, manifest],
-                                 sort=False).reset_index().drop("index",
-                                                                axis=1)
+            manifest = (
+                pd.concat([new_files, manifest], sort=False)
+                .reset_index()
+                .drop("index", axis=1)
+            )
             # update the manifest file, so that it contains the relevant entity IDs
             manifest.to_csv(manifest_filepath, index=False)
 
             # store manifest and update associated metadata with manifest on Synapse
-            manifest_id = self.associateMetadataWithFiles(
-                manifest_filepath, datasetId)
+            manifest_id = self.associateMetadataWithFiles(manifest_filepath, datasetId)
 
         return manifest_id
 
 
-    def getAllManifests(self) -> List[str]:
-        """Gets all metadata manifest files across all datasets in projects a user has access to.
+    def getProjectManifests(self, projectId: str) -> List[str]:
+        """Gets all metadata manifest files across all datasets in a specified project.
 
-        Returns: A list of projects, datasets per project and metadata manifest Synapse ID for each dataset
+        Returns: A list of datasets per project; metadata manifest Synapse ID for each dataset; and the corresponding schema component of the manifest
                  as a list of tuples, one for each manifest:
                     [
                         (
-                            (projectId, projectName),
                             (datasetId, dataName),
-                            (manifestId, manifestName)
+                            (manifestId, manifestName),
+                            (componentSchemaLabel, componentSchemaLabel) TODO: # get component name from schema
                         ),
                         ...
                     ]
 
         TODO: Return manifest URI instead of Synapse ID for interoperability with other implementations of a store interface
-        TODO: Use fileview instead of iterating through projects and datasets
-        TODO: GetDatasetManifest() return type has changed to return only manifest synapse ID. Fetch 
-              manifestName from config.yml and create tuple
         """
 
-        projects = self.getStorageProjects()
 
         manifests = []
-        for projectId, projectName in projects:
 
-            datasets = self.getStorageDatasetsInProject(projectId)
+        datasets = self.getStorageDatasetsInProject(projectId)
 
-            for (datasetId, datasetName) in datasets:
+        for (datasetId, datasetName) in datasets:
+            # encode information about the manifest in a simple list (so that R clients can unpack it)
+            # eventually can serialize differently
 
-                # encode information about the manifest in a simple list (so that R clients can unpack it)
-                # eventually can serialize differently
-                manifest = ((projectId, projectName), (datasetId, datasetName),
-                            self.getDatasetManifest(datasetId))
-
-                manifests.append(manifest)
+            manifest = (
+                    (datasetId, datasetName),
+                    ("", ""),
+                    ("", "")
+            )
+            
+            manifest_info = self.getDatasetManifest(datasetId, downloadFile = True)
+            if manifest_info:
+                manifest_id = manifest_info["properties"]["id"]
+                manifest_name = manifest_info["properties"]["name"]
+                manifest_path = manifest_info["path"]
+                
+                manifest_df = pd.read_csv(manifest_path)
+            
+                if "Component" in manifest_df and  not manifest_df["Component"].empty:
+                    manifest_component = manifest_df["Component"][0]         
+        
+                    manifest = (
+                        (datasetId, datasetName),
+                        (manifest_id, manifest_name),
+                        (manifest_component, manifest_component)
+                    )
+                else:
+                    manifest = (
+                        (datasetId, datasetName),
+                        (manifest_id, manifest_name),
+                        ("", "")
+                    )
+            
+            manifests.append(manifest)
 
         return manifests
 
 
-    def get_synapse_table(
-            self, synapse_id: str) -> Tuple[pd.DataFrame, CsvFileTable]:
+    def get_synapse_table(self, synapse_id: str) -> Tuple[pd.DataFrame, CsvFileTable]:
         """Download synapse table as a pd dataframe; return table schema and etags as results too
-        
+
         Args:
             synapse_id: synapse ID of the table to query
         """
@@ -408,9 +442,9 @@ class SynapseStorage(BaseStorage):
 
         return df, results
 
-
-    def associateMetadataWithFiles(self, metadataManifestPath: str,
-                                   datasetId: str) -> str:
+    def associateMetadataWithFiles(
+        self, metadataManifestPath: str, datasetId: str, useSchemaLabel: bool = True
+    ) -> str:
         """Associate metadata with files in a storage dataset already on Synapse.
         Upload metadataManifest in the storage dataset folder on Synapse as well. Return synapseId of the uploaded manifest file.
 
@@ -420,6 +454,7 @@ class SynapseStorage(BaseStorage):
             Some datasets, e.g. clinical data, do not contain file id's, but data is stored in a table: one row per item.
             In this case, the system creates a file on Synapse for each row in the table (e.g. patient, biospecimen) and associates the columnset data as metadata/annotations to his file.
             datasetId: synapse ID of folder containing the dataset
+            useSchemaLabel: Default is True - use the schema label. If False, uses the display label from the schema. Attribute display names in the schema must not only include characters that are not accepted by Synapse. Annotation names may only contain: letters, numbers, '_' and '.'.
 
         Returns:
             Synapse Id of the uploaded manifest.
@@ -452,7 +487,7 @@ class SynapseStorage(BaseStorage):
         if not "entityId" in manifest.columns:
             manifest["entityId"] = ""
         else:
-            manifest['entityId'].fillna('', inplace=True)
+            manifest["entityId"].fillna("", inplace=True)
 
         # get a schema explorer object to ensure schema attribute names used in manifest are translated to schema labels for synapse annotations
         se = SchemaExplorer()
@@ -475,7 +510,10 @@ class SynapseStorage(BaseStorage):
             #  prepare metadata for Synapse storage (resolve display name into a name that Synapse annotations support (e.g no spaces)
             metadataSyn = {}
             for k, v in row.to_dict().items():
-                keySyn = se.get_class_label_from_display_name(str(k))
+                if useSchemaLabel:
+                    keySyn = se.get_class_label_from_display_name(str(k))
+                else:
+                    keySyn = str(k)
 
                 # truncate annotation values to 500 characters if the
                 # size of values is greater than equal to 500 characters
@@ -494,32 +532,32 @@ class SynapseStorage(BaseStorage):
                 annos[anno_k] = metadataSyn[anno_k]
 
             self.syn.set_annotations(annos)
-            #self.syn.set_annotations(metadataSyn) #-- deprecated code
+            # self.syn.set_annotations(metadataSyn) #-- deprecated code
 
         # update the manifest file, so that it contains the relevant entity IDs
         manifest.to_csv(metadataManifestPath, index=False)
 
         # store manifest to Synapse
-        manifestSynapseFile = File(metadataManifestPath,
-                                   description="Manifest for dataset " +
-                                   datasetId,
-                                   parent=datasetId)
+        manifestSynapseFile = File(
+            metadataManifestPath,
+            description="Manifest for dataset " + datasetId,
+            parent=datasetId,
+        )
         logger.info("Associated manifest file with dataset on Synapse.")
 
         manifestSynapseFileId = self.syn.store(manifestSynapseFile).id
 
         return manifestSynapseFileId
 
-
     def getFileAnnotations(self, fileId: str) -> Dict[str, str]:
         """Generate dictionary of annotations for the given Synapse file.
         Synapse returns all custom annotations as lists since they
         can contain multiple values. In all cases, the values will
         be converted into strings and concatenated with ", ".
-        
+
         Args:
             fileId (str): Synapse ID for dataset file.
-        
+
         Returns:
             dict: Annotations as comma-separated strings.
         """
@@ -552,19 +590,18 @@ class SynapseStorage(BaseStorage):
         # Add the file entity ID and eTag, which weren't lists
         assert fileId == entity.id, (
             "For some reason, the Synapse ID in the response doesn't match"
-            "the Synapse ID sent in the request (via synapseclient).")
+            "the Synapse ID sent in the request (via synapseclient)."
+        )
         annotations["entityId"] = fileId
         annotations["eTag"] = entity.etag
 
         return annotations
 
-
-    def getDatasetAnnotations(self,
-                              datasetId: str,
-                              fill_na: bool = True,
-                              force_batch: bool = False) -> pd.DataFrame:
+    def getDatasetAnnotations(
+        self, datasetId: str, fill_na: bool = True, force_batch: bool = False
+    ) -> pd.DataFrame:
         """Generate table for annotations across all files in given dataset.
-        
+
         Args:
             datasetId (str): Synapse ID for dataset folder.
             fill_na (bool): Whether to replace missing values with
@@ -573,7 +610,7 @@ class SynapseStorage(BaseStorage):
                 the batch mode, which uses a file view to retrieve
                 annotations for a given dataset. Default to False
                 unless there are more than 50 files in the dataset.
-        
+
         Returns:
             pd.DataFrame: Table of annotations.
         """
@@ -587,17 +624,15 @@ class SynapseStorage(BaseStorage):
         try_batch = len(dataset_files) >= 50 or force_batch
         if try_batch:
             try:
-                logger.info(
-                    "Trying batch mode for retrieving Synapse annotations")
-                table = self.getDatasetAnnotationsBatch(
-                    datasetId, dataset_file_ids)
+                logger.info("Trying batch mode for retrieving Synapse annotations")
+                table = self.getDatasetAnnotationsBatch(datasetId, dataset_file_ids)
             except (SynapseAuthenticationError, SynapseHTTPError):
                 logger.info(
                     f"Unable to create a temporary file view bound to {datasetId}. "
-                    "Defaulting to slower iterative retrieval of annotations.")
+                    "Defaulting to slower iterative retrieval of annotations."
+                )
                 # Default to the slower non-batch method
-                logger.info(
-                    "Batch mode failed (probably due to permission error)")
+                logger.info("Batch mode failed (probably due to permission error)")
                 try_batch = False
 
         # Non-batch mode
@@ -625,17 +660,16 @@ class SynapseStorage(BaseStorage):
         # Force all values as strings
         return table.astype(str)
 
-
     def getDatasetProject(self, datasetId: str) -> str:
         """Get parent project for a given dataset ID.
-        
+
         Args:
             datasetId (str): Synapse entity ID (folder or project).
-        
+
         Raises:
             ValueError: Raised if Synapse ID cannot be retrieved
             by the user or if it doesn't appear in the file view.
-        
+
         Returns:
             str: The Synapse ID for the parent project.
         """
@@ -663,24 +697,23 @@ class SynapseStorage(BaseStorage):
         raise ValueError(
             f"The given dataset ({datasetId}) doesn't appear in the "
             f"configured file view ({self.storageFileview}). This might "
-            "mean that the file view's scope needs to be updated.")
-
+            "mean that the file view's scope needs to be updated."
+        )
 
     def getDatasetAnnotationsBatch(
-            self,
-            datasetId: str,
-            dataset_file_ids: Sequence[str] = None) -> pd.DataFrame:
+        self, datasetId: str, dataset_file_ids: Sequence[str] = None
+    ) -> pd.DataFrame:
         """Generate table for annotations across all files in given dataset.
         This function uses a temporary file view to generate a table
         instead of iteratively querying for individual entity annotations.
         This function is expected to run much faster than
         `self.getDatasetAnnotationsBatch` on large datasets.
-        
+
         Args:
             datasetId (str): Synapse ID for dataset folder.
             dataset_file_ids (Sequence[str]): List of Synapse IDs
                 for dataset files/folders used to subset the table.
-        
+
         Returns:
             pd.DataFrame: Table of annotations.
         """
@@ -702,14 +735,17 @@ class DatasetFileView:
     This will ensure that the file view is deleted automatically.
     See SynapseStorage.getDatasetAnnotationsBatch for example usage.
     """
-    def __init__(self,
-                 datasetId: str,
-                 synapse: Synapse,
-                 name: str = None,
-                 temporary: bool = True,
-                 parentId: str = None) -> None:
+
+    def __init__(
+        self,
+        datasetId: str,
+        synapse: Synapse,
+        name: str = None,
+        temporary: bool = True,
+        parentId: str = None,
+    ) -> None:
         """Create a file view scoped to a dataset folder.
-        
+
         Args:
             datasetId (str): Synapse ID for a dataset folder/project.
             synapse (Synapse): Used for Synapse requests.
@@ -742,7 +778,8 @@ class DatasetFileView:
             scopes=self.datasetId,
             includeEntityTypes=[EntityViewType.FILE, EntityViewType.FOLDER],
             addDefaultViewColumns=False,
-            addAnnotationColumns=True)
+            addAnnotationColumns=True,
+        )
 
         # TODO: Handle failure due to insufficient permissions by
         #       creating a temporary new project to store view
@@ -755,38 +792,32 @@ class DatasetFileView:
         # Ensure deletion of the file view (last resort)
         if self.is_temporary:
             atexit.register(self.delete)
-            
-            
+
     def __enter__(self):
         """Return file view when entering 'with' statement."""
         return self
-        
-        
+
     def __exit__(self, exc_type, exc_value, traceback):
         """Delete file view when exiting 'with' statement."""
         if self.is_temporary:
             self.delete()
-            
-            
+
     def delete(self):
         """Delete the file view on Synapse without deleting local table."""
         if self.view_schema is not None:
             self.synapse.delete(self.view_schema)
             self.view_schema = None
-            
-    
+
     def query(self, tidy=True, force=False):
         """Retrieve file view as a data frame (raw format sans index)."""
         if self.table is None or force:
             fileview_id = self.view_schema["id"]
-            self.results = self.synapse.tableQuery(
-                f"select * from {fileview_id}")
+            self.results = self.synapse.tableQuery(f"select * from {fileview_id}")
             self.table = self.results.asDataFrame(rowIdAndVersionInIndex=False)
         if tidy:
             self.tidy_table()
         return self.table
-        
-    
+
     def tidy_table(self):
         """Convert raw file view data frame into more usable format."""
         assert self.table is not None, "Must call `self.query()` first."
@@ -794,8 +825,7 @@ class DatasetFileView:
         self._fix_list_columns()
         self._fix_int_columns()
         return self.table
-        
-    
+
     def _fix_default_columns(self):
         """Rename default columns to match schematic expectations."""
 
@@ -815,8 +845,7 @@ class DatasetFileView:
             self.table.insert(len(self.table.columns), "eTag", row_etags)
 
         return self.table
-        
-        
+
     def _get_columns_of_type(self, types):
         """Helper function to get list of columns of a given type(s)."""
         matching_columns = []
@@ -824,17 +853,15 @@ class DatasetFileView:
             if header.columnType in types:
                 matching_columns.append(header.name)
         return matching_columns
-        
-        
+
     def _fix_list_columns(self):
         """Fix formatting of list-columns."""
-        list_types = {'STRING_LIST', 'INTEGER_LIST', 'BOOLEAN_LIST'}
+        list_types = {"STRING_LIST", "INTEGER_LIST", "BOOLEAN_LIST"}
         list_columns = self._get_columns_of_type(list_types)
         for col in list_columns:
             self.table[col] = self.table[col].apply(lambda x: ", ".join(x))
         return self.table
-        
-        
+
     def _fix_int_columns(self):
         """Ensure that integer-columns are actually integers."""
         int_columns = self._get_columns_of_type({"INTEGER"})
