@@ -4,6 +4,7 @@ import urllib.request
 
 from schematic import CONFIG, LOADER
 
+
 def load_json(file_path):
     """Load json document from file path or url
 
@@ -21,26 +22,22 @@ def load_json(file_path):
 
 
 def export_json(json_doc, file_path):
-    """Export JSON doc to file
-    """
-    with open(file_path, 'w') as f:
-        json.dump(json_doc, f, sort_keys=True,
-                  indent=4, ensure_ascii=False)
+    """Export JSON doc to file"""
+    with open(file_path, "w") as f:
+        json.dump(json_doc, f, sort_keys=True, indent=4, ensure_ascii=False)
 
 
 def load_default():
-    """Load biolink vocabulary
-    """
-    data_path = 'data_models/biothings.model.jsonld'
+    """Load biolink vocabulary"""
+    data_path = "data_models/biothings.model.jsonld"
     biothings_path = LOADER.filename(data_path)
 
     return load_json(biothings_path)
 
 
 def load_schemaorg():
-    """Load SchemOrg vocabulary
-    """
-    data_path = 'data_models/schema_org.model.jsonld'
+    """Load SchemOrg vocabulary"""
+    data_path = "data_models/schema_org.model.jsonld"
     schemaorg_path = LOADER.filename(data_path)
-    
-    return load_json(schemaorg_path)
\ No newline at end of file
+
+    return load_json(schemaorg_path)
